@@ -1,16 +1,16 @@
-/* twepl -c */
-
+#define __TWEPL_APP_C__
 #include "twepl_xcore.c"
 
 int main(int argc, char **argv, char **envp){
 
-   struct stat   fs;
-          FILE  *fo;
-          char  *eb = NULL;
-          char  *in = NULL;
-          char  *on = NULL;
-           int   rv, i;
-           int   cf = 0;
+      TWEPL_CONFIG  cfg;
+  enum TWEPL_STATE  ret;
+              FILE *fo;
+              char *ec = NULL;
+              char *in = NULL;
+              char *on = NULL;
+               int  i;
+               int  cf = 0;
 
   if(argc < 1){
     fprintf(stderr, EPP_APPNAME ": invalid arguments..\n");
@@ -29,7 +29,7 @@ int main(int argc, char **argv, char **envp){
       cf = 1;
     } else if(strcmp(argv[i], "-o") == 0 && i != argc){
       on = argv[++i];
-    } else if(stat(argv[i],&fs) != -1){
+    } else if(access(argv[i], F_OK) != -1){
       in = argv[i];
     }
   }
@@ -48,17 +48,25 @@ int main(int argc, char **argv, char **envp){
     fo = stdout;
   }
 
+  cfg.ParserFlag = OPT_TAG_ALL;
+  cfg.SendLength = 0;
+  cfg.MyApplePie = 0;
+
   if(cf ==1){
-    eb = twepl_file(in , eb, &rv);
-    fprintf(fo, "%s", eb);
+    ret = twepl_file(in , &ec, cfg.ParserFlag);
+    if(ret != TWEPL_OKEY_NOERR){
+      fprintf(stderr, EPP_APPNAME ": parse error.\n");
+      return 1;
+    }
+    fprintf(fo, "%s", ec);
   } else{
-    twepl_script_handler(fo, in, argc, argv, envp);
+    twepl_script_handler(fo, in, argc, argv, envp, &cfg);
   }
 
   if(fo != NULL && fo != stdout)
     fclose(fo);
 
-  free(eb);
+  free(ec);
 
   return 0;
 
